Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1185)

Unified Diff: net/url_request/url_request_context.h

Issue 9317018: referrer_charset is a lie. It's really the user's default_charset. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: Created 8 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/http/http_content_disposition_unittest.cc ('k') | net/url_request/url_request_context.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/url_request/url_request_context.h
===================================================================
--- net/url_request/url_request_context.h (revision 119865)
+++ net/url_request/url_request_context.h (working copy)
@@ -177,11 +177,9 @@
// method to provide a UA string.
virtual const std::string& GetUserAgent(const GURL& url) const;
- // In general, referrer_charset is not known when URLRequestContext is
- // constructed. So, we need a setter.
- const std::string& referrer_charset() const { return referrer_charset_; }
- void set_referrer_charset(const std::string& charset) {
- referrer_charset_ = charset;
+ const std::string& default_charset() const { return default_charset_; }
+ void set_default_charset(const std::string& charset) {
+ default_charset_ = charset;
}
const URLRequestJobFactory* job_factory() const { return job_factory_; }
@@ -219,10 +217,9 @@
scoped_ptr<FtpAuthCache> ftp_auth_cache_;
std::string accept_language_;
std::string accept_charset_;
- // The charset of the referrer where this request comes from. It's not
- // used in communication with a server but is used to construct a suggested
- // filename for file download.
- std::string referrer_charset_;
+ // The user's default charset. It's not used in communication with a server
+ // but is used to construct a suggested filename for file download.
+ std::string default_charset_;
HttpTransactionFactory* http_transaction_factory_;
FtpTransactionFactory* ftp_transaction_factory_;
const URLRequestJobFactory* job_factory_;
« no previous file with comments | « net/http/http_content_disposition_unittest.cc ('k') | net/url_request/url_request_context.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698